from tkinter import *
import webbrowser as wb
import os

try:
    OF_locat = sys._MEIPASS
except:
    OF_locat = ''

class gui_window():

    def __init__(self,window_icon, procedure = False):
        super().__init__()

        # config view
        self.couleur = couleur
        # Window
        self.window = Tk()
        self.menubar = Menu(self.window)
        self.window.wm_attributes("-topmost", 2)
        self.window.resizable(0,0)
        self.window.iconbitmap(os.path.join(OF_locat,window_icon))
        self.window.config(menu=self.menubar)
        self.procedure = procedure

    def help(self):
        wb.open_new(os.path.join(OF_locat, procedure))

    def show(self):
        self.window.mainloop()

    def close(self):
        self.window.destroy()

if __name__ == '__main__':
    gui = gui_window()
    gui.show()


from menu.menu.view import gui_window
from menu.menu.menu_widget import FrameMenu

def show():
    gui = gui_window(menu.menu.img.favicon.ng)
    frame_menu = FrameMenu(gui.window)
    frame_menu.frame_menu.grid()
    gui.show()

if __name__ == '__main__':
    show()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
 
"""Ce module est un test"""

__version__ = "0.0.2"

from menu.get_view import show
from menu.menu.menu_widget import FrameMenu
from menu.menu.view import gui_window


from setuptools import setup, find_packages
import os
import menu

setup(name = 'viewNtTest',
version = menu.__version__,
author = 'Scyther',
author_email = 'leroy_mathieu@live.fr',
keywords = 'test packages views',
classifiers = ['Topic :: Education'],
url='https://github.com/NewtonExpertise/test_pip.git',
packages = find_packages("menu"),
description = 'test_ajout_pip',
long_description = open(os.path.join(os.path.dirname(__file__), 'README.txt')).read(),
license = 'GPL V3',
plateformes = 'ALL',
include_package_data=True,
package_data = {'menu':['.img/favicon.png']}
)


from tkinter import *

try:
    OF_locat = sys._MEIPASS
except:
    OF_locat = ''

class FrameMenu():

    def __init__(self, window, frame_bg='#FFFFFF', label_bg = '#FFFFFF', list_bg_select = '#0099ff'):

        self.frame_menu = Frame(window, background = frame_bg)
        self.var_dossiers = StringVar()
        self.var_dossiers.set("")
        self.var_lab_dossiers = StringVar()
        self.var_lab_dossiers.set("")
        self.var_client = StringVar()
        self.var_base = StringVar()
        
        # label
        self.lab_dossier = Label(self.frame_menu ,  text="Dossiers \ud83d\udd0e",font=('Helvetica', 14, 'bold') , foreground='orange', background=label_bg)
        self.label_select_client = Label(self.frame_menu, textvariable = self.var_lab_dossiers, width = 20, height = 3, wraplength = 160, font=('Helvetica', 10), background=label_bg, anchor="center")

        # Saisie
        self.saisie_dossier = Entry(self.frame_menu ,  width=40, textvariable=self.var_dossiers, cursor='question_arrow')
        self.saisie_dossier.focus_set()

        # # liste 
        self.liste_dossiers = Listbox(self.frame_menu , width=40,  height=10, selectbackground=list_bg_select, cursor="hand2")

        # boutons
        self.generate = Button(self.frame_menu, text = "Sélectionner", width=10)

        # placement 
        self.lab_dossier.grid(row=0,  padx=10, pady=3,sticky='n', columnspan = 2)
        self.saisie_dossier.grid(row=1,  padx=15, pady=5, columnspan = 2)
        self.liste_dossiers.grid(row=2,  padx=15, pady=5, columnspan = 2)
        self.label_select_client.grid(row=8, column=0,  padx=(15,5), pady= 15, sticky='w')
        self.generate.grid(row=8, column=1, padx=(5,15), pady= 15, sticky='e')


if __name__=='__main__':

    from view import gui_window
    gui = gui_window()
    frame_menu = FrameMenu(gui.window)
    frame_menu.frame_menu.grid()
    gui.show()